ete2.phylo.phylotree

Package ete2 :: Package phylo :: Module phylotree |
[hide private]
[frames] | no frames]

# Module phylotree

source code

Classes | [hide private]
| PhyloNode Re-implementation of the standart TreeNode instance.
| PhyloTree Re-implementation of the standart TreeNode instance.

Functions | [hide private]
_parse_species(name) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'`` This module defines the PhyloNode dataytype to manage phylogenetic tree.
| __package__ = ``'``ete2.phylo``'``

Variables Details | [hide private]

  ### __VERSION__ This module defines the PhyloNode dataytype to manage phylogenetic tree. It inheritates the coretype TreeNode and add some speciall features to the the node instances. Value:
      'ete2-2.0rev95'